@@ -11,7 +11,7 @@ from ._models.session import Session
 from ._models.dimension import Dimension, RatioDimension, QuadrantDivider
 from ._models.vertex import Vertex
 from ._utils.xml_utils import parse_gating_xml, export_gatingml
-from ._utils.wsp_utils import parse_wsp
+from ._utils.wsp_utils import parse_wsp, extract_wsp_sample_data
 from ._utils.sample_utils import load_samples, calculate_compensation_from_beads
 
 from ._version import __version__
@@ -30,6 +30,7 @@ __all__ = [
     'parse_gating_xml',
     'export_gatingml',
     'parse_wsp',
+    'extract_wsp_sample_data',
     'load_samples',
     'calculate_compensation_from_beads'
 ]
